pub struct RecordTimes {
pub recorded_at: Timestamp,
pub published_at: Option<Timestamp>,
pub effective_from: Option<Timestamp>,
pub effective_until: Option<Timestamp>,
pub observed_at: Option<Timestamp>,
}Expand description
The distinct times a record can carry. These are never conflated:
recorded_at is when this system first recorded it (ingestion time),
the others are claims about the world and are optional.
Fields
recorded_at: Timestamppublished_at: Option<Timestamp>effective_from: Option<Timestamp>effective_until: Option<Timestamp>observed_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for RecordTimes
impl Clone for RecordTimes
Sourcefn clone(&self) -> RecordTimes
fn clone(&self) -> RecordTimes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecordTimes
impl Debug for RecordTimes
Sourceimpl<'de> Deserialize<'de> for RecordTimes
impl<'de> Deserialize<'de> for RecordTimes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RecordTimes
Sourceimpl PartialEq for RecordTimes
impl PartialEq for RecordTimes
Sourceimpl Serialize for RecordTimes
impl Serialize for RecordTimes
impl StructuralPartialEq for RecordTimes